@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-20079 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,39 +12,23 @@
 #ifndef GOTOLINEDIALOG_H
 #define GOTOLINEDIALOG_H
 
-#include <qvariant.h>
-#include <qdialog.h>
+#include "ui_gotolinedialog.h"
 #include "latexeditor.h"
 
-class QVBoxLayout; 
-class QHBoxLayout; 
-class QGridLayout; 
-class QLabel;
-class QPushButton;
-class QSpinBox;
-
 class GotoLineDialog : public QDialog
 { 
     Q_OBJECT
 
 public:
-    GotoLineDialog(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+    GotoLineDialog(QWidget* parent = 0, const char* name = 0,Qt::WFlags fl = 0 );
     ~GotoLineDialog();
-
-    QLabel* TextLabel1;
-    QSpinBox* spinLine;
-    QPushButton* PushButton2;
-    QPushButton* PushButton1;
-
+    Ui::GotoLineDialog ui;
 
 public slots:
     virtual void gotoLine();
     void SetEditor(LatexEditor *ed);
 
 protected:
-    QGridLayout* GotoLineDialogLayout;
-    QHBoxLayout* Layout1;
-
     LatexEditor *editor;
 };
 
