@@ -1,6 +1,6 @@
 /***************************************************************************
- *   copyright            : (C) 2003 by Pascal Brachet                     *
- *                                                                         *
+ *   copyright       : (C) 2003-2009 by Pascal Brachet                     *
+ *   http://www.xm1math.net/texmaker/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,39 +12,20 @@
 #ifndef TABDIALOG_H
 #define TABDIALOG_H
 
-#include <qspinbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qcombobox.h>
-#include <qtable.h>
-#include <qpushbutton.h>
-#include <qcheckbox.h>
-#include <qdialog.h>
+#include "ui_tabdialog.h"
 
 
-class tabdialog : public QDialog  {
+class TabDialog : public QDialog  {
    Q_OBJECT
 public:
-	tabdialog(QWidget *parent=0, const char *name=0);
-	~tabdialog();
-
-public:
-  QTable* Table1;
-	QSpinBox *spinBoxRows;
-	QSpinBox *spinBoxCollums;
-	QLabel *QLabel_1;
-	QLabel *QLabel_2;
-	QLabel *QLabel_3;
-  QLabel *QLabel_4;
-  QComboBox *combo1;
-  QComboBox *combo2;
-  QCheckBox* checkbox1;
-	QPushButton *buttonOk;
-	QPushButton *buttonCancel;
+	TabDialog(QWidget *parent=0, const char *name=0);
+	~TabDialog();
+	Ui::TabDialog ui;
 
 protected slots:
   void NewRows(int num);
-  void NewCollums(int num);
+  void NewColumns(int num);
+  void HzSepStatus(bool enabled);
 };
 
 
